@@ -7,14 +7,15 @@ from pathlib import Path
 from dataclasses import dataclass
 from albert import *
 
-md_iid = "3.0"
-md_version = "1.10"
+md_iid = "4.0"
+md_version = "1.10.1"
 md_name = "VSCode projects"
 md_description = "Open VSCode projects"
 md_url = "https://github.com/albertlauncher/albert-plugin-python-vscode-projects"
 md_license = "MIT"
 md_bin_dependencies = ["code"]
 md_authors = ["@Sharsie"]
+md_maintainers = ["@Sharsie"]
 
 @dataclass
 class Project:
@@ -73,6 +74,10 @@ class Plugin(PluginInstance, TriggerQueryHandler):
     # Overrides the command to open projects
     _terminalCommand = ""
 
+    @staticmethod
+    def makeIcon():
+        return makeImageIcon(Path(__file__).parent / "icon.svg")
+
     # Setting indicating whether results from the Recent list in VSCode should be searched
     @property
     def recentEnabled(self):
@@ -165,7 +170,6 @@ class Plugin(PluginInstance, TriggerQueryHandler):
         return "project name or path"
 
     def __init__(self):
-        self.iconUrls = [f"file:{Path(__file__).parent}/icon.svg"]
 
         PluginInstance.__init__(self)
 
@@ -358,8 +362,8 @@ Usecase with single VSCode instance - To reuse the VSCode window instead of open
             id=project.path,
             text=project.displayName,
             subtext=f"{subtext}{project.path}",
-            iconUrls=self.iconUrls,
-            inputActionText=project.displayName,
+            icon_factory=Plugin.makeIcon,
+            input_action_text=project.displayName,
             actions=actions,
         )
 
